import os

basedir = os.path.abspath(os.path.dirname(__file__))


class Config:
    KNOWN_MANUAL_INPUTS = [
        "entrada manual",
        "entrada digitada",
        "entrada do usuario",
        "input manual",
        "user input",
        "Input do usuario",
        "input_inesperado",
        "Outro",
        "Outros",
        "recomecar",
        "reiniciar",
        "voltar ao inicio",
        "NaN",
        "None",
        "N/A"
    ]
    
    SCALE_TRANSLATIONS = [
        "Pessimo",
        "Terrivel",
        "Vergonhoso",
        ":tired_face:",
        ":crying_face:",
        "Sad",
        "Muito mal",
        "Muito ruim",
        "Ruim",
        "nao",
        "Nao gostei",
        "Nao curti",
        "Nao resolveu",
        "Nao ajudou",
        "Nao ajuda",
        "Nao adiantou",
        "Nao deu certo",
        "Nao permitiu",
        "Nao satisfez",
        "Insatisfatorio",
        "Nao viabilizou",
        "Nao auxiliou",
        "Nao totalmente",
        "Muito Dificil",
        "Dificil",
        "Fraco",
        "confuso",
        "Demorado",
        "lento",
        "Pode melhorar",
        ":slightly_frowning_face:",
        "Nao sei",
        "Em duvida",
        "Indiferente",
        "Medium",
        "Mais ou menos",
        "Ok",
        "Okay",
        "Na media",
        "Nao quero responder",
        ":neutral_face:",
        "Neutro",
        "Permitiu",
        "Facil",
        "Muito Facil",
        "Viabilizou",
        "Auxiliou",
        "Adiantou",
        "Regular",
        "Satisfatorio",
        "Satisfeito",
        "Resolveu",
        "Favoreceu",
        "Ajuda",
        "Ajudou",
        "Ajuda sim",
        "Ajuda_sim",
        "Ajudou sim",
        "Ajudou_sim",
        "Sim, ajudou",
        "Sim, ajuda",
        "Bom",
        "Legal",
        "Apreciei",
        "Gostei",
        "Happy",
        ":slightly_smiling_face:",
        "Muito bem",
        "muito_bem",
        "Muito bom",
        "muito_bom",
        "Gostei muito",
        "Otimo",
        "Apreciei",
        "Adorei",
        "Amei",
        ":smiling_face_with_heart-eyes:",
        "Excelente"
    ]
