"""This project calculates the satisfaction rate for BLiP smart contacts.

It should be passed the full scale and amount per scale for the satisfaction rate core.

Methods:
_________
    * run: Run Take Satisfaction for given dataframe.
"""

__author__ = "squad XD"
__version__ = "1.0.0"

from .run import run
